@@ -12,13 +12,11 @@ using namespace ost;
 int main(int argc, char* argv[])
 {
    slog("slogTest", Slog::classUser, Slog::levelInfo);
-   slog.error() << "Howdy daemon and clog." << endl;
+   slog << "Howdy daemon and clog." << endl;
    slog.clogEnable(false);
-   slog.info() << "This is only for the daemon." << endl;
+   slog << "This is only for the daemon." << endl;
    slog.clogEnable(true);
-   slog.warn() << "Are you still there?" << endl;
-   slog.level(Slog::levelNotice);
-   slog.debug() << "I should not output, below level info" << endl;
+   slog << "Are you still there?" << endl;
    return 0;
 }
 
