@@ -201,7 +201,7 @@ public:
 	/**
 	 * Create a lifo pager as a mempager.
 	 *
-	 * @param page size for allocation
+	 * @param pagesize for memory allocation
 	 */
 	StackPager(size_t pagesize);
 
@@ -209,10 +209,10 @@ public:
 	 * Push an arbitrary object onto the stack.
 	 *
 	 * @return stack memory location.
-	 * @param pointer to data
+	 * @param object pointer to data
 	 * @param size of data.
 	 */
-	void *push(const void *object, size_t len);
+	void *push(const void *object, size_t size);
 
 	/**
 	 * Push a string onto the stack.
@@ -430,9 +430,9 @@ public:
 	 * filename that is directly passed rather than a computed key
 	 * path.  This also uses a [keys] section as passed to the object.
 	 *
-	 * @param filename to load from
-	 * @param key value set to parse, or NULL to parse from head
-	 * @param optional key prefix
+	 * @param filepath to load from
+	 * @param keys section to parse from, or NULL to parse from head
+	 * @param pre optional key prefix
 	 */
 	void loadFile(const char *filepath, const char *keys = NULL, const char *pre = NULL);
 
@@ -464,8 +464,8 @@ public:
 	 * Alternate constructor can take a define list and an optional
 	 * pathfile to parse.
 	 *
-	 * @param define list
-	 * @param keypath (filepath/section)
+	 * @param pairs of keyword values from a define list
+	 * @param keypath of optional file and section to load from 
 	 */
 	Keydata(Define *pairs, const char *keypath = NULL);
 
@@ -673,7 +673,7 @@ public:
 	/**
 	 * Create a new runlist with a specified limit.
 	 *
-	 * @param limit before wait queuing.
+	 * @param count limit before wait queuing.
 	 */
 	Runlist(unsigned count = 1);
 	
@@ -683,7 +683,7 @@ public:
 	 * otherwise the entry is added to the list.
 	 *
 	 * @return true if immediately ready to run
-	 * @param runable object.
+	 * @param run pointer to runable object.
 	 */
 	bool add(Runable *run);
 
@@ -691,7 +691,7 @@ public:
 	 * Remove a runable object from the wait list or notify when
 	 * it is done running so that the used count can be decremented.
 	 *
-	 * @param runable object.
+	 * @param run pointer to runable object.
 	 */
 	void del(Runable *run);
 
