@@ -260,41 +260,47 @@ protected:
 	Error receiveLimit(int limit = 1);
 
 	/**
-	 * Set the send timeout.
+	 * Set the send timeout for sending raw network data.
 	 *
 	 * @return errSuccess if set.
-	 * @param timeout value in millisec.
+	 * @param timer value in millisec.
 	 */
-	Error sendTimeout(timeout_t to);
+	Error sendTimeout(timeout_t timer);
 
 	/**
-	 * Receive timeout.
+	 * Receive timeout for receiving raw network data.
+	 *
+	 * @return errSuccess if set.
+	 * @param timer value in milliseconds.
 	 */
-	Error receiveTimeout(timeout_t to);
+	Error receiveTimeout(timeout_t timer);
 
 	/**
-	 * Set the send buffer size.
+	 * Set the protocol stack network kernel send buffer size 
+	 * associated with the socket.
 	 *
 	 * @return errSuccess on success, or error.
-	 * @param size of buffer.
+	 * @param size of buffer in bytes.
 	 */
-	Error sendBuffer(unsigned bufsize);
+	Error sendBuffer(unsigned size);
 
         /**
-         * Set the receive buffer size.
+         * Set the protocol stack network kernel receive buffer size
+	 * associated with the socket.
          * 
          * @return errSuccess on success, or error. 
-         * @param size of buffer.
+         * @param size of buffer in bytes.
          */
-        Error receiveBuffer(unsigned bufsize);
+        Error receiveBuffer(unsigned size);
 
 	/**
-	 * Set the total buffer size bidirectionally.
+	 * Set the total protocol stack network kernel buffer size 
+	 * for both send and receive together.
 	 *
 	 * @return errSuccess on success
 	 * @param size of buffer.
 	 */
-	Error bufferSize(unsigned bufsize);
+	Error bufferSize(unsigned size);
 
 	/**
 	 * Set the subnet broadcast flag for the socket.  This enables
@@ -315,6 +321,7 @@ protected:
 	 *
 	 * @return 0 (errSuccess) on success, else error code.
 	 * @param enable when set to true.
+	 * @param family of protocol.
 	 */
 	Error setMulticastByFamily(bool enable, Family family = IPV4);
 
@@ -324,6 +331,7 @@ protected:
 	 *
 	 * @return 0 (errSuccess) on success, else error code.
 	 * @param enable when set to true.
+	 * @param family of protocol.
 	 */
 	Error setLoopbackByFamily(bool enable, Family family = IPV4);
 
@@ -332,6 +340,7 @@ protected:
 	 *
 	 * @return 0 (errSuccess) on success, else error code.
 	 * @param ttl time to live.
+	 * @param fam family of protocol.
 	 */
 	Error setTimeToLiveByFamily(unsigned char ttl, Family fam = IPV4);
 
@@ -445,7 +454,6 @@ protected:
          */
         virtual ssize_t writeData(const void* buf,size_t len,timeout_t t=0);
 
-
 public:
 	/**
 	 * The socket base class may be "thrown" as a result of an
@@ -819,7 +827,7 @@ public:
 	 *
 	 * @param buf pointer to packet buffer to receive.
 	 * @param len of packet buffer to receive.
-	 * @param save sender address as peer to send reply if true.
+	 * @param reply save sender address for reply if true.
 	 * @return number of bytes received.
 	 */
 	ssize_t receive(void *buf, size_t len, bool reply = false);
@@ -1256,7 +1264,7 @@ public:
 	 * @param bind local ip address or interface to use.
 	 * @param port number to bind socket under.
 	 * @param backlog size of connection request queue.
-	 * @param buffer size for accepted streams.
+	 * @param mss maximum segment size for accepted streams.
 	 */
 	TCPSocket(const IPV4Address &bind, tpport_t port, unsigned backlog = 5, unsigned mss = 536);
 
@@ -1268,8 +1276,9 @@ public:
 	 *
 	 * @param name of host interface and service port to bind.
 	 * @param backlog size of connection request queue.
+	 * @param mss maximum segment size for streaming buffers.
 	 */
-	TCPSocket(const char *service, unsigned backlog = 5, unsigned mss = 536);
+	TCPSocket(const char *name, unsigned backlog = 5, unsigned mss = 536);
 	
 	/**
 	 * Return address and port of next connection request.  This
@@ -1371,6 +1380,7 @@ public:
 	 * @param bind local ip address or interface to use.
 	 * @param port number to bind socket under.
 	 * @param backlog size of connection request queue.
+	 * @param mss maximum segment size of streaming buffer.
 	 */
 	TCPV6Socket(const IPV6Address &bind, tpport_t port, unsigned backlog = 5, unsigned mss = 536);
 
@@ -1382,8 +1392,9 @@ public:
 	 *
 	 * @param name of host interface and service to use.
 	 * @param backlog size of connection request queue.
+	 * @param mss maximum segment size of streaming buffers.
 	 */
-	TCPV6Socket(const char *service, unsigned backlog = 5, unsigned mss = 536);
+	TCPV6Socket(const char *name, unsigned backlog = 5, unsigned mss = 536);
 	
 	/**
 	 * Return address and port of next connection request.  This
@@ -1528,7 +1539,7 @@ protected:
 	 *
 	 * @param host address of remote TCP server.
 	 * @param port number to connect.
-	 * @param size of streaming input and output buffers.
+	 * @param mss maximum segment size of streaming buffers.
 	 */
 	void connect(const IPV4Host &host, tpport_t port, unsigned mss = 536);
 #ifdef	CCXX_IPV6
@@ -1540,9 +1551,9 @@ protected:
 	 * number, using getaddrinfo interface if available.
 	 *
 	 * @param name of host and service to connect
-	 * @param size of stream buffer
+	 * @param mss maximum segment size of stream buffer
 	 */
-	void connect(const char *service, unsigned mss = 536);
+	void connect(const char *name, unsigned mss = 536);
 
 	/**
 	 * Used in derived classes to refer to the current object via
@@ -1561,7 +1572,6 @@ public:
 	 * call.
 	 *
 	 * @param server socket listening
-	 * @param size of streaming input and output buffers.
 	 * @param throwflag flag to throw errors.
 	 * @param timeout for all operations.
 	 */
@@ -1586,7 +1596,7 @@ public:
 	 *
 	 * @param host address of remote TCP server.
 	 * @param port number to connect.
-	 * @param size of streaming input and output buffers.
+	 * @param mss maximum segment size of streaming buffers.
 	 * @param throwflag flag to throw errors.
 	 * @param timeout for all operations.
 	 */
@@ -1600,24 +1610,24 @@ public:
 	 *
 	 * @param name of remote service.
 	 * @param family of protocol.
-	 * @param size of streaming buffers.
+	 * @param mss maximum segment size of streaming buffers.
 	 * @param throwflag flag to throw errors.
-	 * @param timeout for all operations.
+	 * @param timer for timeout for all operations.
 	 */
-	TCPStream(const char *service, Family fam = IPV4, unsigned mss = 536, bool throwflag = false, timeout_t to = 0);
+	TCPStream(const char *name, Family family = IPV4, unsigned mss = 536, bool throwflag = false, timeout_t timer = 0);
 
 	/**
 	 * Set the I/O operation timeout for socket I/O operations.
 	 *
-	 * @param to timeout to set.
+	 * @param timer to change timeout.
 	 */
-	inline void setTimeout(timeout_t to)
-		{timeout = to;};
+	inline void setTimeout(timeout_t timer)
+		{timeout = timer;};
 
 	/**
 	 * A copy constructor creates a new stream buffer.
 	 *
-	 * @param source of copy.
+	 * @param source reference of stream to copy from.
 	 *
 	 */
 	TCPStream(const TCPStream &source);
@@ -1735,7 +1745,6 @@ public:
 	 * connection.
 	 * 
 	 * @param server tcp socket to accept a connection from.
-	 * @param size of streaming buffer.
 	 * @param pri execution priority relative to parent.
 	 * @param stack allocation needed on some platforms.
 	 */
