@@ -56,14 +56,6 @@ using namespace std;
 const uint32 MAX_BUFFER = 16384;
 #endif
 
-#ifdef  CCXX_EXCEPTIONS
-Engine::Exception::Exception(const String &reason):
-  PersistException(reason) 
-{
-}
-
-#endif
-
 /**
  * NullObject is a const uint32 which is the ID streamed to disk
  * if an attempt to stream a NULL Persistence::BaseObject or
@@ -102,7 +94,7 @@ Engine::Engine(std::iostream& stream, EngineMode mode) THROWS (PersistException)
     myZStream.avail_out = MAX_BUFFER;
     int err = deflateInit(&myZStream,9); // TODO: tweak compression level
     if (err != Z_OK) {
-      THROW ( PersistException(String("zLib didn't initialise for deflating.")));
+      THROW (PersistException(String("zLib didn't initialise for deflating.")));
     }
   }
 #endif
@@ -146,7 +138,7 @@ Engine::~Engine()
 }
 
 void Engine::writeBinary(const uint8* data, const uint32 size) 
-  THROWS (Engine::Exception)
+  THROWS (PersistException)
 {
   if(myOperationalMode != modeWrite)
     THROW("Cannot write to an input Engine");
@@ -189,7 +181,7 @@ void Engine::writeBinary(const uint8* data, const uint32 size)
 #endif
 }
 
-void Engine::readBinary(uint8* data, uint32 size) THROWS (Engine::Exception)
+void Engine::readBinary(uint8* data, uint32 size) THROWS (PersistException)
 {
   if(myOperationalMode != modeRead)
     THROW("Cannot read from an output Engine");
@@ -248,7 +240,7 @@ void Engine::readBinary(uint8* data, uint32 size) THROWS (Engine::Exception)
  * note, does not (yet?) throw an exception, but interface
  * prepared ..
  */
-void Engine::write(const BaseObject *object) THROWS (Engine::Exception)
+void Engine::write(const BaseObject *object) THROWS (PersistException)
 {
   // Pre-step, if object is NULL, then don't serialise it - serialise a
   // marker to say that it is null.
@@ -297,7 +289,7 @@ void Engine::write(const BaseObject *object) THROWS (Engine::Exception)
 /*
  * reads in a BaseObject into a reference (pre-instantiated object)
  */
-void Engine::read(BaseObject &object) THROWS (Engine::Exception)
+void Engine::read(BaseObject &object) THROWS (PersistException)
 {
   uint32 id = 0;
   read(id);
@@ -322,7 +314,7 @@ void Engine::read(BaseObject &object) THROWS (Engine::Exception)
 /*
  * reads in a BaseObject into a pointer allocating if the pointer is NULL
  */
-void Engine::read(BaseObject *&object) THROWS (Engine::Exception)
+void Engine::read(BaseObject *&object) THROWS (PersistException)
 {
   uint32 id = 0;
   read(id);
@@ -364,24 +356,24 @@ void Engine::read(BaseObject *&object) THROWS (Engine::Exception)
 /*
  * reads the actual object data in
  */
-void Engine::readObject(BaseObject* object)
+void Engine::readObject(BaseObject* object) THROWS (PersistException)
 {
   // Okay then - we can make this object
   myArchiveVector.push_back(object);
   String majik;
   read(majik);
   if(majik != String("OBST"))
-    THROW("Missing Start-of-Object marker");
+    THROW( Exception("Missing Start-of-Object marker"));
   object->read(*this);
   read(majik);
   if(majik != String("OBEN"))
-    THROW("Missing End-of-Object marker");
+    THROW( Exception("Missing End-of-Object marker"));
 }
 
 /*
  * reads the class information in
  */
-const String Engine::readClass()
+const String Engine::readClass() THROWS (PersistException)
 {
   // Okay - read the identifier for the class in...
   uint32 classId = 0;
@@ -406,14 +398,14 @@ const String Engine::readClass()
  * note, does not (yet?) throw an exception, but interface
  * prepared ..
  */
-void Engine::write(const String& str) THROWS (Engine::Exception)
+void Engine::write(const String& str) THROWS (PersistException)
 {
   uint32 len = (uint32)str.length();
   write(len);
   writeBinary((uint8*)str.c_str(),len);
 }
 
-void Engine::read(String& str) THROWS (Engine::Exception)
+void Engine::read(String& str) THROWS (PersistException)
 {
   uint32 len = 0;
   read(len);
@@ -428,14 +420,14 @@ void Engine::read(String& str) THROWS (Engine::Exception)
  * note, does not (yet?) throw an exception, but interface
  * prepared ..
  */
-void Engine::write(const std::string& str) THROWS (Engine::Exception)
+void Engine::write(const std::string& str) THROWS (PersistException)
 {
   uint32 len = (uint32)str.length();
   write(len);
   writeBinary((uint8*)str.c_str(),len);
 }
 
-void Engine::read(std::string& str) THROWS (Engine::Exception)
+void Engine::read(std::string& str) THROWS (PersistException)
 {
   uint32 len = 0;
   read(len);
@@ -449,53 +441,53 @@ void Engine::read(std::string& str) THROWS (Engine::Exception)
 #define CCXX_RE(ar,ob)   ar.read(ob); return ar
 #define CCXX_WE(ar,ob)   ar.write(ob); return ar
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject &ob) THROWS (Engine::Exception) {CCXX_RE(ar,ob);}
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject *&ob) THROWS (Engine::Exception) {CCXX_RE(ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const &ob) THROWS (Engine::Exception) {CCXX_WE(ar,&ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const *ob) THROWS (Engine::Exception) {CCXX_WE(ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject &ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject *&ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const &ob) THROWS (PersistException) {CCXX_WE(ar,&ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const *ob) THROWS (PersistException) {CCXX_WE(ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int8& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int8 ob) THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, int8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, int8 ob) THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint8& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint8 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint8 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int16& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int16 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, int16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, int16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint16& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint16 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int32& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int32 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, int32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, int32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint32& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint32 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
 #ifdef  HAVE_64_BITS
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int64& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int64 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, int64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, int64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint64& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint64 ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 #endif
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, float& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, float ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, float& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, float ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, double& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, double ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, double& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, double ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, String& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, String ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, String& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, String ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, std::string& ob) THROWS (Engine::Exception) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, std::string ob)  THROWS (Engine::Exception) {CCXX_WE (ar,ob);}
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, std::string& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, std::string ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, bool& ob) THROWS (Engine::Exception) {
+CCXX_EXPORT(Engine&) operator >>( Engine& ar, bool& ob) THROWS (PersistException) {
   uint32 a; ar.read(a); ob=a==1;return ar;
 }
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, bool ob) THROWS (Engine::Exception) {
+CCXX_EXPORT(Engine&) operator <<( Engine& ar, bool ob) THROWS (PersistException) {
   uint32 a=ob?1:0; ar.write(a); return ar;
 }
 
